@@ -1,3 +1,5 @@
+from typing import Any
+
 import httpx
 from pydantic import BaseModel, NonNegativeFloat, PositiveInt
 
@@ -9,10 +11,12 @@ class AsyncHTTPClientParams(BaseModel):
     keepalive_expiry: float | None = 5
 
 
-def create_async_http_client(
-    client_params: AsyncHTTPClientParams,
+def create_simple_async_httpx_client(
+    client_params: AsyncHTTPClientParams | dict[str, Any],
 ) -> httpx.AsyncClient:
-    http_client = httpx.AsyncClient(
+    if isinstance(client_params, dict):
+        client_params = AsyncHTTPClientParams(**client_params)
+    return httpx.AsyncClient(
         timeout=httpx.Timeout(client_params.timeout),
         limits=httpx.Limits(
             max_connections=client_params.max_connections,
@@ -20,5 +24,3 @@ def create_async_http_client(
             keepalive_expiry=client_params.keepalive_expiry,
         ),
     )
-
-    return http_client
