@@ -1,11 +1,13 @@
 import json
 from collections.abc import Hashable, Mapping, Sequence
 from enum import StrEnum
-from typing import Annotated, Any, Literal, TypeAlias
+from typing import Annotated, Any, Literal, Required, TypeAlias
 from uuid import uuid4
 
+from litellm.types.llms.openai import ChatCompletionAnnotation as LiteLLMAnnotation
 from pydantic import BaseModel, Field
 from pydantic.json import pydantic_encoder
+from typing_extensions import TypedDict
 
 from .content import Content, ImageData
 from .tool import ToolCall
@@ -14,6 +16,7 @@ from .tool import ToolCall
 class Role(StrEnum):
     USER = "user"
     SYSTEM = "system"
+    DEVELOPER = "developer"
     ASSISTANT = "assistant"
     TOOL = "tool"
 
@@ -23,11 +26,32 @@ class MessageBase(BaseModel):
     name: str | None = None
 
 
+class ChatCompletionCachedContent(TypedDict):
+    type: Literal["ephemeral"]
+
+
+class ThinkingBlock(TypedDict, total=False):
+    type: Required[Literal["thinking"]]
+    thinking: str
+    signature: str | None
+    cache_control: dict[str, Any] | ChatCompletionCachedContent | None
+
+
+class RedactedThinkingBlock(TypedDict, total=False):
+    type: Required[Literal["redacted_thinking"]]
+    data: str
+    cache_control: dict[str, Any] | ChatCompletionCachedContent | None
+
+
 class AssistantMessage(MessageBase):
     role: Literal[Role.ASSISTANT] = Role.ASSISTANT
     content: str | None
     tool_calls: Sequence[ToolCall] | None = None
     refusal: str | None = None
+    reasoning_content: str | None = None
+    thinking_blocks: Sequence[ThinkingBlock | RedactedThinkingBlock] | None = None
+    annotations: Sequence[LiteLLMAnnotation] | None = None
+    provider_specific_fields: dict[str, Any] | None = None
 
 
 class UserMessage(MessageBase):
