@@ -60,14 +60,26 @@ class BaseTool(
         return self._out_type
 
     @abstractmethod
-    async def run(self, inp: _InT, ctx: RunContext[CtxT] | None = None) -> _OutT_co:
+    async def run(
+        self,
+        inp: _InT,
+        *,
+        ctx: RunContext[CtxT] | None = None,
+        call_id: str | None = None,
+    ) -> _OutT_co:
         pass
 
     async def __call__(
-        self, ctx: RunContext[CtxT] | None = None, **kwargs: Any
+        self,
+        *,
+        ctx: RunContext[CtxT] | None = None,
+        call_id: str | None = None,
+        **kwargs: Any,
     ) -> _OutT_co:
+        # NOTE: validation is probably redundant here when tool inputs have been
+        # validated by the LLM already
         input_args = TypeAdapter(self._in_type).validate_python(kwargs)
-        output = await self.run(input_args, ctx=ctx)
+        output = await self.run(input_args, ctx=ctx, call_id=call_id)
 
         return TypeAdapter(self._out_type).validate_python(output)
 
